// -*-Mode: C++;-*-  
#ifndef TABVIEW_H
#define TABVIEW_H

#include <klistview.h>
#include <string>
#include "kmysqladmin/helpers/stringlist.h"

class TabView : public KListView
{
    Q_OBJECT
protected:
    std::string tmp_string;
public:
    TabView(QWidget * = 0, const char * = 0);
    void fitAll(void);
    void setColumns(QString);
    virtual void clear();
    int count();
    int current();
    const char*text(int i);
    void line(int which, stringlist&target);
};

#endif
